@@ -34,7 +34,7 @@ from .node import (
     NodeTLHasChanged,
     NodeTLHasChangedSummary,
 )
-from .types import ConnectionInfo, Parameters
+from .types import ConnectionInfo, Parameters, SyncType
 
 DEFAULT_CFG = "config.ini"
 handler = logging.StreamHandler()
@@ -229,10 +229,11 @@ def cluster_node_count(
     \b
     The role refers to the role of the server in the cluster. Possible values
     are:
-    * master or leader
+    * leader (master was removed in patroni 4.0.0)
     * replica
     * standby_leader
     * sync_standby
+    * quorum_standby
     * demoted
     * promoted
     * uninitialized
@@ -252,7 +253,7 @@ def cluster_node_count(
     The "healthy" checks only ensures that:
     * a leader has the running state
     * a standby_leader has the running or streaming (V3.0.4) state
-    * a replica or sync-standby has the running or streaming (V3.0.4) state
+    * a replica, quorum_standby or sync_standby has the running or streaming (V3.0.4) state
 
     Since we dont check the lag or timeline, "in archive recovery" is not considered a valid state
     for this service. See cluster_has_leader and cluster_has_replica for specialized checks.
@@ -360,6 +361,13 @@ def cluster_has_leader(ctx: click.Context) -> None:
     type=str,
     help="Critical threshold for the number of sync replica.",
 )
+@click.option(
+    "--sync-type",
+    type=click.Choice(["any", "sync", "quorum"], case_sensitive=True),
+    default="any",
+    show_default=True,
+    help="Synchronous replication mode used to filter and count sync standbies.",
+)
 @click.option("--max-lag", "max_lag", type=str, help="maximum allowed lag")
 @click.pass_context
 @nagiosplugin.guarded
@@ -369,9 +377,10 @@ def cluster_has_replica(
     critical: str,
     sync_warning: str,
     sync_critical: str,
+    sync_type: SyncType,
     max_lag: str,
 ) -> None:
-    """Check if the cluster has healthy replicas and/or if some are sync standbies
+    """Check if the cluster has healthy replicas and/or if some are sync or quorum standbies
 
     \b
     For patroni (and this check):
@@ -380,7 +389,7 @@ def cluster_has_replica(
 
     \b
     A healthy replica:
-    * has a `replica` or `sync_standby` role
+    * has a `replica`, `quorum_standby` or `sync_standby` role
     * has the same timeline as the leader and
       * is in `running` state (patroni < V3.0.4)
       * is in `streaming` or `in archive recovery` state (patroni >= V3.0.4)
@@ -397,16 +406,24 @@ def cluster_has_replica(
     switchover or failover and the standbies are in the process of catching up with
     the new leader. The alert shouldn't last long.
 
+    In PostgreSQL, synchronous replication has two modes: on and quorum and is
+    configured with the gucs `synchronous_standby_names` and `synchronous_commit`. Patroni
+    uses the parameter `synchronous_mode`, which can be set to `on`, `quorum` and `off`,
+    and has `synchronous_node_count` to configure the synchronous replication factor.
+    Please note that, in synchronous replication, the number of servers tagged as "{sync|quorum}_standby"
+    (what we measure) is not always equal tot `synchronous_node_count`.
+
     \b
     Check:
     * `OK`: if the healthy_replica count and their lag are compatible with the replica count threshold.
-            and if the sync_replica count is compatible with the sync replica count threshold.
+            and if the synchronous replica count is compatible with the sync replica count threshold.
     * `WARNING` / `CRITICAL`: otherwise
 
     \b
     Perfdata:
     * healthy_replica & unhealthy_replica count
-    * the number of sync_replica, they are included in the previous count
+    * the number of sync_replica (sync or quorum depending on `--sync-type`), they are included
+      in the previous count
     * the lag of each replica labelled with "member name"_lag
     * the timeline of each replica labelled with "member name"_timeline
     * a boolean to tell if the node is a sync stanbdy labelled with "member name"_sync
@@ -415,7 +432,7 @@ def cluster_has_replica(
     tmax_lag = size_to_byte(max_lag) if max_lag is not None else None
     check = nagiosplugin.Check()
     check.add(
-        ClusterHasReplica(ctx.obj.connection_info, tmax_lag),
+        ClusterHasReplica(ctx.obj.connection_info, tmax_lag, sync_type),
         nagiosplugin.ScalarContext(
             "healthy_replica",
             warning,
@@ -609,6 +626,13 @@ def node_is_leader(ctx: click.Context, check_standby_leader: bool) -> None:
     default=False,
     help="check if the replica is synchronous",
 )
+@click.option(
+    "--sync-type",
+    type=click.Choice(["any", "sync", "quorum"], case_sensitive=True),
+    default="any",
+    show_default=True,
+    help="Synchronous replication mode.",
+)
 @click.option(
     "--is-async",
     "check_is_async",
@@ -619,7 +643,11 @@ def node_is_leader(ctx: click.Context, check_standby_leader: bool) -> None:
 @click.pass_context
 @nagiosplugin.guarded
 def node_is_replica(
-    ctx: click.Context, max_lag: str, check_is_sync: bool, check_is_async: bool
+    ctx: click.Context,
+    max_lag: str,
+    check_is_sync: bool,
+    check_is_async: bool,
+    sync_type: SyncType,
 ) -> None:
     """Check if the node is a replica with no noloadbalance tag.
 
@@ -658,9 +686,11 @@ def node_is_replica(
 
     check = nagiosplugin.Check()
     check.add(
-        NodeIsReplica(ctx.obj.connection_info, max_lag, check_is_sync, check_is_async),
+        NodeIsReplica(
+            ctx.obj.connection_info, max_lag, check_is_sync, check_is_async, sync_type
+        ),
         nagiosplugin.ScalarContext("is_replica", None, "@0:0"),
-        NodeIsReplicaSummary(max_lag, check_is_sync, check_is_async),
+        NodeIsReplicaSummary(max_lag, check_is_sync, check_is_async, sync_type),
     )
     check.main(verbose=ctx.obj.verbose, timeout=ctx.obj.timeout)
 
@@ -789,12 +819,15 @@ def node_patroni_version(ctx: click.Context, patroni_version: str) -> None:
 @nagiosplugin.guarded
 def node_is_alive(ctx: click.Context) -> None:
     """Check if the node is alive ie patroni is running. This is
-    a liveness check as defined in Patroni's documentation.
+    a liveness check as defined in Patroni's documentation. If
+    patroni is not running, we have no way to know if the provided
+    endpoint is valid, therefore the check returns UNKNOWN.
 
     \b
     Check:
-    * `OK`: If patroni is running.
-    * `CRITICAL`: otherwise.
+    * `OK`: If patroni the liveness check returns with HTTP status 200.
+    * `CRITICAL`: if partoni's liveness check returns with an HTTP status
+       other than 200.
 
     \b
     Perfdata:
