@@ -6,7 +6,7 @@ from typing import Any, Iterable, Union
 import nagiosplugin
 
 from . import _log
-from .types import ConnectionInfo, PatroniResource, handle_unknown
+from .types import ConnectionInfo, PatroniResource, SyncType, handle_unknown
 
 
 def replace_chars(text: str) -> str:
@@ -45,7 +45,12 @@ class ClusterNodeCount(PatroniResource):
                 debug_member(member, "healthy")
                 continue
 
-            if role in ["standby_leader", "replica", "sync_standby"] and (
+            if role in [
+                "standby_leader",
+                "replica",
+                "sync_standby",
+                "quorum_standby",
+            ] and (
                 (self.has_detailed_states() and state == "streaming")
                 or (not self.has_detailed_states() and state == "running")
             ):
@@ -128,9 +133,15 @@ class ClusterHasLeaderSummary(nagiosplugin.Summary):
 
 
 class ClusterHasReplica(PatroniResource):
-    def __init__(self, connection_info: ConnectionInfo, max_lag: Union[int, None]):
+    def __init__(
+        self,
+        connection_info: ConnectionInfo,
+        max_lag: Union[int, None],
+        sync_type: SyncType,
+    ):
         super().__init__(connection_info)
         self.max_lag = max_lag
+        self.sync_type = sync_type
 
     def probe(self) -> Iterable[nagiosplugin.Metric]:
         def debug_member(member: Any, health: str) -> None:
@@ -156,7 +167,7 @@ class ClusterHasReplica(PatroniResource):
 
         # Look for replicas
         for member in cluster_item_dict["members"]:
-            if member["role"] in ["replica", "sync_standby"]:
+            if member["role"] in ["replica", "sync_standby", "quorum_standby"]:
                 if member["lag"] == "unknown":
                     # This could happen if the node is stopped
                     # nagiosplugin doesn't handle strings in perfstats
@@ -170,7 +181,11 @@ class ClusterHasReplica(PatroniResource):
                             "name": member["name"],
                             "lag": member["lag"],
                             "timeline": member["timeline"],
-                            "sync": 1 if member["role"] == "sync_standby" else 0,
+                            "sync": (
+                                1
+                                if member["role"] in ["sync_standby", "quorum_standby"]
+                                else 0
+                            ),
                         }
                     )
 
@@ -180,7 +195,7 @@ class ClusterHasReplica(PatroniResource):
                     # members because leader_tl will remain None. it's not
                     # a big deal since having no leader is rare.
                     for tmember in cluster_item_dict["members"]:
-                        if tmember["role"] == "leader":
+                        if tmember["role"] in ["leader", "standby_leader"]:
                             leader_tl = int(tmember["timeline"])
                             break
 
@@ -209,7 +224,13 @@ class ClusterHasReplica(PatroniResource):
                     unhealthy_replica += 1
                     continue
 
-                if member["role"] == "sync_standby":
+                if (
+                    self.sync_type in ["sync", "any"]
+                    and member["role"] == "sync_standby"
+                ) or (
+                    self.sync_type in ["quorum", "any"]
+                    and member["role"] == "quorum_standby"
+                ):
                     sync_replica += 1
 
                 if self.max_lag is None or self.max_lag >= int(member["lag"]):
