@@ -1,6 +1,6 @@
 import json
 from functools import lru_cache
-from typing import Any, Callable, List, Optional, Tuple, Union
+from typing import Any, Callable, List, Literal, Optional, Tuple, Union
 from urllib.parse import urlparse
 
 import attr
@@ -9,10 +9,12 @@ import requests
 
 from . import _log
 
+SyncType = Literal["any", "sync", "quorum"]
+
 
 class APIError(requests.exceptions.RequestException):
-    """This exception is raised when the rest api couldn't
-    be reached and we got a http status code different from 200.
+    """This exception is raised when the rest api could
+    be reached but we got a http status code different from 200.
     """
 
 
