@@ -1,22 +1,25 @@
+from typing import Iterator
+
+import pytest
 from click.testing import CliRunner
-from pytest_mock import MockerFixture
 
 from check_patroni.cli import main
 
-from .tools import my_mock
+from . import PatroniAPI
 
 
-def test_node_patroni_version_ok(
-    mocker: MockerFixture, use_old_replica_state: bool
-) -> None:
-    runner = CliRunner()
+@pytest.fixture(scope="module", autouse=True)
+def node_patroni_version(patroni_api: PatroniAPI) -> Iterator[None]:
+    with patroni_api.routes({"patroni": "node_patroni_version.json"}):
+        yield None
 
-    my_mock(mocker, "node_patroni_version", 200)
+
+def test_node_patroni_version_ok(runner: CliRunner, patroni_api: PatroniAPI) -> None:
     result = runner.invoke(
         main,
         [
             "-e",
-            "https://10.20.199.3:8008",
+            patroni_api.endpoint,
             "node_patroni_version",
             "--patroni-version",
             "2.0.2",
@@ -29,17 +32,12 @@ def test_node_patroni_version_ok(
     )
 
 
-def test_node_patroni_version_ko(
-    mocker: MockerFixture, use_old_replica_state: bool
-) -> None:
-    runner = CliRunner()
-
-    my_mock(mocker, "node_patroni_version", 200)
+def test_node_patroni_version_ko(runner: CliRunner, patroni_api: PatroniAPI) -> None:
     result = runner.invoke(
         main,
         [
             "-e",
-            "https://10.20.199.3:8008",
+            patroni_api.endpoint,
             "node_patroni_version",
             "--patroni-version",
             "1.0.0",
