@@ -7,7 +7,7 @@ fi
 
 echo "-- Running patroni checks using endpoint $1"
 echo "-- Cluster checks"
-check_patroni -e "$1" cluster_config_has_changed --state-file cluster.sate_file --save
+check_patroni -e "$1" cluster_config_has_changed --state-file cluster.state_file --save
 check_patroni -e "$1" cluster_has_leader
 check_patroni -e "$1" cluster_has_replica
 check_patroni -e "$1" cluster_is_in_maintenance
@@ -20,5 +20,5 @@ check_patroni -e "$1" node_is_primary
 check_patroni -e "$1" node_is_leader --is-standby-leader
 check_patroni -e "$1" node_is_replica
 check_patroni -e "$1" node_is_replica --is-sync
-check_patroni -e "$1" node_patroni_version --patroni-version 3.1.0
-check_patroni -e "$1" node_tl_has_changed --state-file cluster.sate_file --save
+check_patroni -e "$1" node_patroni_version --patroni-version 4.0.2
+check_patroni -e "$1" node_tl_has_changed --state-file cluster.state_file --save
